package be.iminds.ilabt.jfed.ui.javafx.automated_testing_gui;

import be.iminds.ilabt.jfed.ui.javafx.GlyphUtils;
import be.iminds.ilabt.jfed.ui.javafx.GuiceFXMLUtil;
import javafx.scene.control.ButtonBar;
import javafx.scene.control.ButtonType;
import javafx.scene.control.Dialog;
import javafx.scene.paint.Color;
import org.controlsfx.glyphfont.FontAwesome;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.inject.Inject;

public class LoadConfigFromUrlDialog extends Dialog<LoadConfigFromUrlDialog.LoadConfigFromUrlDialogResult> {
    private static final Logger LOG = LoggerFactory.getLogger(LoadConfigFromUrlDialog.class);

    public static class LoadConfigFromUrlDialogResult {
        @Nonnull private final String testClassName;
        @Nullable private final String testGroup;
        @Nullable private final String config;
        @Nullable private final Integer serverId;

        public LoadConfigFromUrlDialogResult(@Nonnull String testClassName, @Nullable String testGroup, @Nullable String config, @Nullable Integer serverId) {
            this.testClassName = testClassName;
            this.testGroup = testGroup;
            this.config = config;
            this.serverId = serverId;
        }

        @Nonnull
        public String getTestClassName() {
            return testClassName;
        }

        @Nullable
        public String getTestGroup() {
            return testGroup;
        }

        @Nullable
        public String getConfig() {
            return config;
        }

        @Nullable
        public Integer getServerId() {
            return serverId;
        }
    }

    private final LoadConfigFromUrlController controller;

    @Inject
    public LoadConfigFromUrlDialog(GuiceFXMLUtil guiceFXMLUtil) {
        GuiceFXMLUtil.Result<?, LoadConfigFromUrlController> fxmlResult =
                guiceFXMLUtil.createFromFXML(LoadConfigFromUrlController.class);
        this.controller = fxmlResult.getController();

        setTitle("Fetch config from Fedmon URL");
        getDialogPane().setContent(fxmlResult.getRoot());
        setGraphic(GlyphUtils.createDialogGlyph(FontAwesome.Glyph.HDD_ALT, Color.BLACK));

        ButtonType loadConfigFromUrlButtonType = new ButtonType("Load Config", ButtonBar.ButtonData.OK_DONE);
        getDialogPane().getButtonTypes().setAll(loadConfigFromUrlButtonType, ButtonType.CANCEL);

        setResultConverter(param -> {
            if (param == loadConfigFromUrlButtonType) {
                return controller.getConfig();
            } else
                return null;
        });
    }
}
